================================================
Wrapper for file descriptors - mushroom.geventfd
================================================

.. contents::
    :local:

.. currentmodule:: mushroom.geventfd

.. automodule:: mushroom.geventfd
    :members:
    :undoc-members:
